@@ -52,7 +52,7 @@ class ElasticsearchAdapter(ElasticsearchPort):
         if configs.API_KEY and configs.API_SECRET:
             api_key = ((configs.API_KEY, configs.API_SECRET),)
         elif configs.HTTP_USER_NAME and configs.HTTP_PASSWORD:
-            basic_auth = ((configs.HTTP_USER_NAME, configs.HTTP_PASSWORD),)
+            basic_auth = (configs.HTTP_USER_NAME, configs.HTTP_PASSWORD.get_secret_value())
 
         return Elasticsearch(
             hosts=configs.HOSTS,
@@ -258,6 +258,23 @@ class ElasticsearchAdapter(ElasticsearchPort):
         """
         return self.client.exists(index=index, id=doc_id, **kwargs)
 
+    @override
+    def index_exists(
+        self,
+        index: ElasticsearchIndexType,
+        **kwargs: object,
+    ) -> ElasticsearchResponseType:
+        """Check if an index exists in Elasticsearch.
+
+        Args:
+            index (ElasticsearchIndexType): The index name.
+            kwargs: Additional keyword arguments passed to the Elasticsearch client.
+
+        Returns:
+            ElasticsearchResponseType: True if the index exists, False otherwise.
+        """
+        return self.client.indices.exists(index=index, **kwargs)
+
 
 class AsyncElasticsearchAdapter(AsyncElasticsearchPort):
     """Concrete implementation of the AsyncElasticsearchPort interface using elasticsearch-py library.
@@ -293,7 +310,7 @@ class AsyncElasticsearchAdapter(AsyncElasticsearchPort):
         if configs.API_KEY and configs.API_SECRET:
             api_key = (configs.API_KEY, configs.API_SECRET)
         elif configs.HTTP_USER_NAME and configs.HTTP_PASSWORD:
-            basic_auth = (configs.HTTP_USER_NAME, configs.HTTP_PASSWORD)
+            basic_auth = (configs.HTTP_USER_NAME, configs.HTTP_PASSWORD.get_secret_value())
 
         return AsyncElasticsearch(
             hosts=configs.HOSTS,
@@ -495,3 +512,20 @@ class AsyncElasticsearchAdapter(AsyncElasticsearchPort):
             ElasticsearchResponseType: True if the document exists, False otherwise.
         """
         return await self.client.exists(index=index, id=doc_id, **kwargs)
+
+    @override
+    async def index_exists(
+        self,
+        index: ElasticsearchIndexType,
+        **kwargs: object,
+    ) -> ElasticsearchResponseType:
+        """Check if an index exists in Elasticsearch.
+
+        Args:
+            index (ElasticsearchIndexType): The index name.
+            kwargs: Additional keyword arguments passed to the Elasticsearch client.
+
+        Returns:
+            ElasticsearchResponseType: True if the index exists, False otherwise.
+        """
+        return await self.client.indices.exists(index=index, **kwargs)
