@@ -1,9 +1,8 @@
+from datetime import datetime
 from typing import ClassVar
 
-from sqlalchemy import Boolean, Column, DateTime, ForeignKey
-from sqlalchemy.orm import DeclarativeBase, Synonym
-
-from archipy.helpers.utils.base_utils import BaseUtils
+from sqlalchemy import Boolean, Column, DateTime, ForeignKey, func
+from sqlalchemy.orm import DeclarativeBase, Mapped, Synonym
 
 PK_COLUMN_NAME = "pk_uuid"
 
@@ -21,7 +20,7 @@ class BaseEntity(DeclarativeBase):
     """
 
     __abstract__ = True
-    created_at = Column(DateTime(), default=BaseUtils.get_datetime_now, nullable=False)
+    created_at: Mapped[datetime] = Column(DateTime(), server_default=func.now(), nullable=False)
 
     @classmethod
     def _is_abstract(cls) -> bool:
@@ -118,11 +117,12 @@ class UpdatableMixin:
     """
 
     __abstract__ = True
+
     updated_at = Column(
         DateTime(),
-        default=BaseUtils.get_datetime_now,
+        server_default=func.now(),
         nullable=False,
-        onupdate=BaseUtils.get_datetime_now,
+        onupdate=func.now(),
     )
 
 
